numpy.flatiter
==============

.. currentmodule:: numpy

.. autoclass:: flatiter

   

   .. HACK
      .. autosummary::
         :toctree:
      
         flatiter.__init__
         flatiter.copy
         flatiter.next



   

   .. HACK
      .. autosummary::
         :toctree:
      
         flatiter.base
         flatiter.coords
         flatiter.index

